tlslite.SessionCache.SessionCache

Package tlslite :: Module SessionCache :: Class SessionCache |
[show private | hide private]
[frames | no frames]

## Class SessionCache

This class is used by the server to cache TLS sessions.

Caching sessions allows the client to use TLS session resumption and avoid the expense of a full handshake. To use this class, simply pass a SessionCache instance into the server handshake function.

This class is thread-safe.

Method Summary
| ``__init__`(self, maxEntries, maxAge)` Create a new SessionCache.
| `__getitem__(self, sessionID)`
| `__setitem__(self, sessionID, session)`

Method Details

### __init__(self, maxEntries=10000, maxAge=14400) (Constructor) Create a new SessionCache. Parameters: `maxEntries` - The maximum size of the cache. When this limit is reached, the oldest sessions will be deleted as necessary to make room for new ones. The default is 10000. (type=int) `maxAge` - The number of seconds before a session expires from the cache. The default is 14400 (i.e. 4 hours). (type=int)

Generated by Epydoc 2.0 on Mon Feb 21 21:56:54 2005 | http://epydoc.sf.net